# Screenly OSE API Client

[![image](https://img.shields.io/pypi/v/screenly_ose.svg)](https://pypi.python.org/pypi/screenly_ose)

[![image](https://img.shields.io/travis/burnnat/screenly_ose.svg)](https://travis-ci.org/burnnat/screenly_ose)

Library to enable control of Screenly OSE digital signage via REST API.

  - Free software: MIT license

## Features

  - TODO

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.